# coding: utf-8

__doc__ = "模块的 import 使用名与模块的发布名对照表"

import_name = {
    "PIL": "Pillow",
    "PyISAPI_loader": "pywin32",
    "adodbapi": "pywin32",
    "adsi": "pywin32",
    "afxres": "pywin32",
    "authorization": "pywin32",
    "axcontrol": "pywin32",
    "axdebug": "pywin32",
    "axscript": "pywin32",
    "bits": "pywin32",
    "bs4": "beautifulsoup4",
    "commctrl": "pywin32",
    "cv2": "opencv-python",
    "dbi": "pywin32",
    "dde": "pywin32",
    "directsound": "pywin32",
    "exchange": "pywin32",
    "exchdapi": "pywin32",
    "ifilter": "pywin32",
    "importlib_metadata": "importlib-metadata",
    "internet": "pywin32",
    "isapi": "pywin32",
    "mapi": "pywin32",
    "mmapfile": "pywin32",
    "mmsystem": "pywin32",
    "netbios": "pywin32",
    "ntsecuritycon": "pywin32",
    "odbc": "pywin32",
    "perfmon": "pywin32",
    "perfmondata": "pywin32",
    "pkg_resources": "setuptools",
    "propsys": "pywin32",
    "pythoncom": "pywin32",
    "pythonwin": "pywin32",
    "pywin32_bootstrap": "pywin32",
    "pywin32_testutil": "pywin32",
    "pywintypes": "pywin32",
    "rasutil": "pywin32",
    "regcheck": "pywin32",
    "regutil": "pywin32",
    "servicemanager": "pywin32",
    "shell": "pywin32",
    "sspi": "pywin32",
    "sspicon": "pywin32",
    "taskscheduler": "pywin32",
    "timer": "pywin32",
    "win2kras": "pywin32",
    "win32api": "pywin32",
    "win32clipboard": "pywin32",
    "win32com": "pywin32",
    "win32comext": "pywin32",
    "win32con": "pywin32",
    "win32console": "pywin32",
    "win32cred": "pywin32",
    "win32crypt": "pywin32",
    "win32cryptcon": "pywin32",
    "win32ctypes": "pywin32-ctypes",
    "win32event": "pywin32",
    "win32evtlog": "pywin32",
    "win32evtlogutil": "pywin32",
    "win32file": "pywin32",
    "win32gui": "pywin32",
    "win32gui_struct": "pywin32",
    "win32help": "pywin32",
    "win32inet": "pywin32",
    "win32inetcon": "pywin32",
    "win32job": "pywin32",
    "win32lz": "pywin32",
    "win32net": "pywin32",
    "win32netcon": "pywin32",
    "win32pdh": "pywin32",
    "win32pdhquery": "pywin32",
    "win32pdhutil": "pywin32",
    "win32pipe": "pywin32",
    "win32print": "pywin32",
    "win32process": "pywin32",
    "win32profile": "pywin32",
    "win32ras": "pywin32",
    "win32rcparser": "pywin32",
    "win32security": "pywin32",
    "win32service": "pywin32",
    "win32serviceutil": "pywin32",
    "win32timezone": "pywin32",
    "win32trace": "pywin32",
    "win32traceutil": "pywin32",
    "win32transaction": "pywin32",
    "win32ts": "pywin32",
    "win32ui": "pywin32",
    "win32uiole": "pywin32",
    "win32verstamp": "pywin32",
    "win32wnet": "pywin32",
    "winerror": "pywin32",
    "winioctlcon": "pywin32",
    "winnt": "pywin32",
    "winperf": "pywin32",
    "winxpgui": "pywin32",
    "winxptheme": "pywin32",
}
