# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'addenv_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_input_dialog(object):
    def setupUi(self, input_dialog):
        input_dialog.setObjectName("input_dialog")
        input_dialog.setWindowModality(QtCore.Qt.WindowModal)
        input_dialog.resize(580, 74)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        input_dialog.setFont(font)
        self.centralwidget = QtWidgets.QWidget(input_dialog)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(8, 16, 8, 8)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.uiLineEdit_input_content = QtWidgets.QLineEdit(self.centralwidget)
        self.uiLineEdit_input_content.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.uiLineEdit_input_content.setObjectName("uiLineEdit_input_content")
        self.horizontalLayout.addWidget(self.uiLineEdit_input_content)
        self.uiPushButton_select_envdir = QtWidgets.QPushButton(self.centralwidget)
        self.uiPushButton_select_envdir.setObjectName("uiPushButton_select_envdir")
        self.horizontalLayout.addWidget(self.uiPushButton_select_envdir)
        self.uiPushButton_confirm = QtWidgets.QPushButton(self.centralwidget)
        self.uiPushButton_confirm.setObjectName("uiPushButton_confirm")
        self.horizontalLayout.addWidget(self.uiPushButton_confirm)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.label = QtWidgets.QLabel(self.centralwidget)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(100, 100, 100))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(100, 100, 100))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(120, 120, 120))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
        self.label.setPalette(palette)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(9)
        self.label.setFont(font)
        self.label.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label.setWordWrap(True)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.verticalLayout.setStretch(1, 1)
        input_dialog.setCentralWidget(self.centralwidget)

        self.retranslateUi(input_dialog)
        QtCore.QMetaObject.connectSlotsByName(input_dialog)

    def retranslateUi(self, input_dialog):
        _translate = QtCore.QCoreApplication.translate
        input_dialog.setWindowTitle(_translate("input_dialog", "输入内容"))
        self.uiPushButton_select_envdir.setToolTip(_translate("input_dialog", "打开目录选择窗口，选择 python.exe 文件所在的目录。"))
        self.uiPushButton_select_envdir.setText(_translate("input_dialog", "选择"))
        self.uiPushButton_confirm.setText(_translate("input_dialog", "确定"))
        self.label.setText(_translate("input_dialog", "粘贴 “python.exe” 文件所在目录路径或点击“选择”按钮选择 “python.exe” 文件所在目录然后点击确定。"))
