# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'environ_chosen.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_environ_chosen(object):
    def setupUi(self, environ_chosen):
        environ_chosen.setObjectName("environ_chosen")
        environ_chosen.setWindowModality(QtCore.Qt.WindowModal)
        environ_chosen.resize(420, 200)
        environ_chosen.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.centralwidget = QtWidgets.QWidget(environ_chosen)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        self.centralwidget.setFont(font)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(8, 8, 8, 8)
        self.verticalLayout.setObjectName("verticalLayout")
        self.lw_environ_list = QtWidgets.QListWidget(self.centralwidget)
        self.lw_environ_list.setObjectName("lw_environ_list")
        self.verticalLayout.addWidget(self.lw_environ_list)
        self.label = QtWidgets.QLabel(self.centralwidget)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(91, 91, 91))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(91, 91, 91))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(120, 120, 120))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
        self.label.setPalette(palette)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(9)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        environ_chosen.setCentralWidget(self.centralwidget)

        self.retranslateUi(environ_chosen)
        QtCore.QMetaObject.connectSlotsByName(environ_chosen)

    def retranslateUi(self, environ_chosen):
        _translate = QtCore.QCoreApplication.translate
        environ_chosen.setWindowTitle(_translate("environ_chosen", "选择 Python 环境"))
        self.label.setText(_translate("environ_chosen", "需要先在包管理器中添加环境，这里才会显示可供选择的项~"))
