# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'show_download.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_show_download(object):
    def setupUi(self, show_download):
        show_download.setObjectName("show_download")
        show_download.setWindowModality(QtCore.Qt.WindowModal)
        show_download.resize(260, 500)
        self.centralwidget = QtWidgets.QWidget(show_download)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        self.centralwidget.setFont(font)
        self.centralwidget.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(8, 8, 8, 8)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tw_downloading = QtWidgets.QTableWidget(self.centralwidget)
        self.tw_downloading.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tw_downloading.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.tw_downloading.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tw_downloading.setCornerButtonEnabled(False)
        self.tw_downloading.setObjectName("tw_downloading")
        self.tw_downloading.setColumnCount(2)
        self.tw_downloading.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tw_downloading.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tw_downloading.setHorizontalHeaderItem(1, item)
        self.tw_downloading.horizontalHeader().setHighlightSections(False)
        self.tw_downloading.horizontalHeader().setStretchLastSection(True)
        self.tw_downloading.verticalHeader().setHighlightSections(False)
        self.verticalLayout.addWidget(self.tw_downloading)
        show_download.setCentralWidget(self.centralwidget)

        self.retranslateUi(show_download)
        QtCore.QMetaObject.connectSlotsByName(show_download)

    def retranslateUi(self, show_download):
        _translate = QtCore.QCoreApplication.translate
        show_download.setWindowTitle(_translate("show_download", "下载列表"))
        item = self.tw_downloading.horizontalHeaderItem(0)
        item.setText(_translate("show_download", "下载项"))
        item = self.tw_downloading.horizontalHeaderItem(1)
        item.setText(_translate("show_download", "下载状态"))
