# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'package_manager.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_package_manager(object):
    def setupUi(self, package_manager):
        package_manager.setObjectName("package_manager")
        package_manager.setWindowModality(QtCore.Qt.WindowModal)
        package_manager.resize(900, 620)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        package_manager.setFont(font)
        self.centralwidget = QtWidgets.QWidget(package_manager)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_6.setContentsMargins(8, 8, 8, 8)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.splitter = QtWidgets.QSplitter(self.centralwidget)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setHandleWidth(6)
        self.splitter.setObjectName("splitter")
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSpacing(2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.lb_python_dir = QtWidgets.QLabel(self.layoutWidget)
        self.lb_python_dir.setMinimumSize(QtCore.QSize(0, 25))
        self.lb_python_dir.setObjectName("lb_python_dir")
        self.verticalLayout.addWidget(self.lb_python_dir)
        self.lw_env_list = QtWidgets.QListWidget(self.layoutWidget)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(0, 120, 215))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(155, 222, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.HighlightedText, brush)
        self.lw_env_list.setPalette(palette)
        self.lw_env_list.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.lw_env_list.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.lw_env_list.setObjectName("lw_env_list")
        self.verticalLayout.addWidget(self.lw_env_list)
        self.verticalLayout.setStretch(1, 1)
        self.verticalLayout_3.addLayout(self.verticalLayout)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btn_autosearch = QtWidgets.QPushButton(self.layoutWidget)
        self.btn_autosearch.setObjectName("btn_autosearch")
        self.horizontalLayout.addWidget(self.btn_autosearch)
        self.btn_addmanully = QtWidgets.QPushButton(self.layoutWidget)
        self.btn_addmanully.setObjectName("btn_addmanully")
        self.horizontalLayout.addWidget(self.btn_addmanully)
        self.btn_delselected = QtWidgets.QPushButton(self.layoutWidget)
        self.btn_delselected.setObjectName("btn_delselected")
        self.horizontalLayout.addWidget(self.btn_delselected)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.verticalLayout_3.setStretch(0, 1)
        self.layoutWidget1 = QtWidgets.QWidget(self.splitter)
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSpacing(2)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.lb_installed_pkgs_info = QtWidgets.QLabel(self.layoutWidget1)
        self.lb_installed_pkgs_info.setObjectName("lb_installed_pkgs_info")
        self.horizontalLayout_4.addWidget(self.lb_installed_pkgs_info)
        spacerItem = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.le_search_pkgs_kwd = QtWidgets.QLineEdit(self.layoutWidget1)
        self.le_search_pkgs_kwd.setClearButtonEnabled(True)
        self.le_search_pkgs_kwd.setObjectName("le_search_pkgs_kwd")
        self.horizontalLayout_4.addWidget(self.le_search_pkgs_kwd)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.tw_installed_info = QtWidgets.QTableWidget(self.layoutWidget1)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(0, 120, 215))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(155, 222, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.HighlightedText, brush)
        self.tw_installed_info.setPalette(palette)
        self.tw_installed_info.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tw_installed_info.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tw_installed_info.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.tw_installed_info.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tw_installed_info.setCornerButtonEnabled(False)
        self.tw_installed_info.setColumnCount(4)
        self.tw_installed_info.setObjectName("tw_installed_info")
        self.tw_installed_info.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tw_installed_info.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tw_installed_info.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tw_installed_info.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tw_installed_info.setHorizontalHeaderItem(3, item)
        self.tw_installed_info.horizontalHeader().setHighlightSections(False)
        self.tw_installed_info.verticalHeader().setHighlightSections(False)
        self.verticalLayout_2.addWidget(self.tw_installed_info)
        self.verticalLayout_2.setStretch(1, 1)
        self.verticalLayout_4.addLayout(self.verticalLayout_2)
        self.glo_table_btns = QtWidgets.QGridLayout()
        self.glo_table_btns.setObjectName("glo_table_btns")
        self.btn_upgrade_package = QtWidgets.QPushButton(self.layoutWidget1)
        self.btn_upgrade_package.setObjectName("btn_upgrade_package")
        self.glo_table_btns.addWidget(self.btn_upgrade_package, 1, 2, 1, 1)
        self.btn_check_for_updates = QtWidgets.QPushButton(self.layoutWidget1)
        self.btn_check_for_updates.setObjectName("btn_check_for_updates")
        self.glo_table_btns.addWidget(self.btn_check_for_updates, 0, 3, 1, 1)
        self.btn_install_package = QtWidgets.QPushButton(self.layoutWidget1)
        self.btn_install_package.setObjectName("btn_install_package")
        self.glo_table_btns.addWidget(self.btn_install_package, 1, 0, 1, 1)
        self.lb_num_selected_items = QtWidgets.QLabel(self.layoutWidget1)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(8)
        self.lb_num_selected_items.setFont(font)
        self.lb_num_selected_items.setObjectName("lb_num_selected_items")
        self.glo_table_btns.addWidget(self.lb_num_selected_items, 0, 0, 1, 1)
        self.btn_uninstall_package = QtWidgets.QPushButton(self.layoutWidget1)
        self.btn_uninstall_package.setObjectName("btn_uninstall_package")
        self.glo_table_btns.addWidget(self.btn_uninstall_package, 1, 1, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_2.setText("")
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.cb_check_uncheck_all = QtWidgets.QCheckBox(self.layoutWidget1)
        self.cb_check_uncheck_all.setObjectName("cb_check_uncheck_all")
        self.horizontalLayout_2.addWidget(self.cb_check_uncheck_all)
        self.glo_table_btns.addLayout(self.horizontalLayout_2, 0, 1, 1, 1)
        self.uiPushButton_show_output = QtWidgets.QPushButton(self.layoutWidget1)
        self.uiPushButton_show_output.setObjectName("uiPushButton_show_output")
        self.glo_table_btns.addWidget(self.uiPushButton_show_output, 0, 2, 1, 1)
        self.btn_upgrade_all = QtWidgets.QPushButton(self.layoutWidget1)
        self.btn_upgrade_all.setObjectName("btn_upgrade_all")
        self.glo_table_btns.addWidget(self.btn_upgrade_all, 1, 3, 1, 1)
        self.verticalLayout_4.addLayout(self.glo_table_btns)
        self.verticalLayout_4.setStretch(0, 1)
        self.verticalLayout_5.addWidget(self.splitter)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setContentsMargins(-1, -1, 4, -1)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.lb_loading_gif = QtWidgets.QLabel(self.centralwidget)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(8)
        self.lb_loading_gif.setFont(font)
        self.lb_loading_gif.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lb_loading_gif.setObjectName("lb_loading_gif")
        self.horizontalLayout_3.addWidget(self.lb_loading_gif)
        self.lb_loading_tip = QtWidgets.QLabel(self.centralwidget)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(8)
        self.lb_loading_tip.setFont(font)
        self.lb_loading_tip.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.lb_loading_tip.setObjectName("lb_loading_tip")
        self.horizontalLayout_3.addWidget(self.lb_loading_tip)
        self.horizontalLayout_3.setStretch(0, 1)
        self.verticalLayout_5.addLayout(self.horizontalLayout_3)
        self.verticalLayout_5.setStretch(0, 1)
        self.verticalLayout_6.addLayout(self.verticalLayout_5)
        package_manager.setCentralWidget(self.centralwidget)

        self.retranslateUi(package_manager)
        QtCore.QMetaObject.connectSlotsByName(package_manager)

    def retranslateUi(self, package_manager):
        _translate = QtCore.QCoreApplication.translate
        package_manager.setWindowTitle(_translate("package_manager", "包管理器"))
        self.lb_python_dir.setToolTip(_translate("package_manager", "显示当前搜索到的/用户添加的 Python 目录路径。"))
        self.lb_python_dir.setText(_translate("package_manager", "Python 环境："))
        self.lw_env_list.setToolTip(_translate("package_manager", "使用鼠标左键点击加载选中的 Python 环境已安装的包信息列表，使用鼠标右键点击或使用上下方向键选择则不加载。"))
        self.btn_autosearch.setToolTip(_translate("package_manager", "自动搜索常用安装位置中的 Python 目录并将路径添加到 Python 环境列表保存。"))
        self.btn_autosearch.setText(_translate("package_manager", "自动搜索"))
        self.btn_addmanully.setToolTip(_translate("package_manager", "手动将 Python 目录路径添加到本 Python 环境列表以便下次使用。"))
        self.btn_addmanully.setText(_translate("package_manager", "手动添加"))
        self.btn_delselected.setToolTip(_translate("package_manager", "将 Python 环境列表中的选中项移除(不会删除本机 Python 目录)。"))
        self.btn_delselected.setText(_translate("package_manager", "移除选中项"))
        self.lb_installed_pkgs_info.setToolTip(_translate("package_manager", "选中的 Python 环境中已安装的包名、当前版本、最新版本、安装状态信息。"))
        self.lb_installed_pkgs_info.setText(_translate("package_manager", "已安装的包信息："))
        self.le_search_pkgs_kwd.setPlaceholderText(_translate("package_manager", "搜索"))
        item = self.tw_installed_info.horizontalHeaderItem(0)
        item.setText(_translate("package_manager", "名称"))
        item = self.tw_installed_info.horizontalHeaderItem(1)
        item.setText(_translate("package_manager", "当前版本"))
        item = self.tw_installed_info.horizontalHeaderItem(2)
        item.setText(_translate("package_manager", "最新版本"))
        item = self.tw_installed_info.horizontalHeaderItem(3)
        item.setText(_translate("package_manager", "状态"))
        self.btn_upgrade_package.setToolTip(_translate("package_manager", "升级表格中被选中的包。\n"
"注意，被选中的包如果没有新版本则不升级，支持多选。"))
        self.btn_upgrade_package.setText(_translate("package_manager", "升级"))
        self.btn_check_for_updates.setToolTip(_translate("package_manager", "检查选中的 Python 环境中的所有模块的最新版本，有新版本则在\"最新版本\"列中显示版本号。"))
        self.btn_check_for_updates.setText(_translate("package_manager", "检查更新"))
        self.btn_install_package.setToolTip(_translate("package_manager", "将输入的包名安装到选中的 Python 环境中。\n"
"多个包名请用空格隔开，支持输入与 pip 命令 install 选项相同的参数。"))
        self.btn_install_package.setText(_translate("package_manager", "安装"))
        self.btn_uninstall_package.setToolTip(_translate("package_manager", "将表格中选中的包卸载(仅从选中的 Python 环境中卸载)。\n"
"注意，卸载时表格中的条目支持多选。"))
        self.btn_uninstall_package.setText(_translate("package_manager", "卸载"))
        self.cb_check_uncheck_all.setText(_translate("package_manager", "全选"))
        self.uiPushButton_show_output.setText(_translate("package_manager", "输出窗口"))
        self.btn_upgrade_all.setToolTip(_translate("package_manager", "升级表格中列出的所有显示有新版本的包。\n"
"使用此功能前请先点击\"检查更新\"按钮以检查是否有新版本，再点击此按钮升级。"))
        self.btn_upgrade_all.setText(_translate("package_manager", "升级全部"))
